.. _tutorials:

===========================
Tutorials
===========================

Tutorials give selected application examples to get familiar with typical use cases.

Tutorials are provided as Jupyter notebooks.


.. toctree::
   :maxdepth: 1
   :caption: Tutorials about LocData
   :name: toc_tutorials_data

   LocData <./notebooks/LocData>
   Load localization data <./notebooks/Load_LocData>
   Hulls <./notebooks/LocData_hulls>
   Metadata <./notebooks/Metadata>

   Regions <./notebooks/Regions>
   Filter <./notebooks/Filter_LocData>
   Cluster <./notebooks/Cluster_LocData>
   Render <./notebooks/Render_LocData>
   Simulate <./notebooks/Simulate_LocData>
   Track <./notebooks/Track_LocData>
   Transform <./notebooks/Transform_LocData>


.. toctree::
   :maxdepth: 1
   :caption: Tutorials about analysis procedures
   :name: toc_tutorials_analysis

   Localizations per frame <./notebooks/Analysis_localizations_per_frame>
   Localization precision <./notebooks/Analysis_localization_precision>
   Localization property <./notebooks/Analysis_localization_property>

   Blinking <./notebooks/Analysis_Blinking>
   Coordinate based colocalization <./notebooks/Analysis_coordinate_based_colocalization>
   Drift <./notebooks/Analysis_Drift>
   Nearest neighbor distances <./notebooks/Analysis_nearest_neighbor_distances>
   Ripley <./notebooks/Analysis_Ripley>

   Example <./notebooks/Analysis_example>
   How to use an analysis class <./notebooks/Analysis_how_to_use_an_analysis_class>
   Analysis pipeline <./notebooks/Analysis_pipeline>
   Multiprocessing <./notebooks/Multiprocessing_with_ray>


.. toctree::
   :maxdepth: 1
   :caption: Other tutorials
   :name: toc_tutorials_misc

   Datasets <./notebooks/Example Datasets>
   Logging <./notebooks/Logging>


.. toctree::
   :maxdepth: 1
   :caption: More
   :name: notebook_execution_table

   Notebook execution table <notebook_execution_table>
